gs_quant.timeseries.algebra.exp — gs_quant 0.1 documentation

# gs_quant.timeseries.algebra.exp

`exp`(x)

  Exponential of series

  Parameters

    x (`Series`) – timeseries

  Return type

    `Series`

  Returns

    exponential of each element

  Usage

  For each element in the series, \(X_t\), raise \(e\) (Euler’s number) to the power of \(X_t\). Euler’s number is the base of the natural logarithm, \(ln\).

  \(R_t = e^{X_t}\)

  Examples

  Raise \(e\) to the power \(1\). Returns Euler’s number, approximately 2.71828

      >>> exp(1)

  See also

  `log()`